#ifndef main_h_INCLUDED
#define main_h_INCLUDED

#include <string>

#include <BsplineEval/bsplineval.h>

#include "config.h"


#ifdef HAVE_DASL_DBL
#include <dasl_dbl/cprotos.h>
#endif


#define VERSION_LENGTH 255
#define NAME_LENGTH 255
#define DEBUG_LENGTH 255

typedef struct
{
  BsplineInput* bsp;
  spline_coef scoef;

#ifdef HAVE_DASL_DBL

  /*--------------------------------------------------------------------
   * workspaces
   */

  /* lwmax  = MX_theta_order * MX_MTHETA + MX_num_theta_knots
   *        + MX_num_theta_knots + MX_z_order + 2 * MX_ORDR ) */

  integer lwmax;                 /* size of double  work array */
  doublereal*  dbl_workspace;    /* double workspace           */

  /* liwmax  = MX_MTHETA + MX_num_theta_knots + MX_theta_order */

  integer      liwmax;           /* size of integer work array */
  integer*     int_workspace;    /* integer workspace          */

#endif

} SplineInfo;


typedef struct
{
  std::string        prgname;          /* name of executable    */

  std::string        input;            /* name of input stream  */
  std::string        prefix;           /* output file prefix  */

  std::string	     method1;
  std::string	     method2;

  int num;

} Common;


typedef BsplineErr
         (*EvalSpline)(double theta, double zn,
		       SplineInfo& spinfo, double* s);

typedef BsplineErr
          (*EvalSplineDeriv)(double theta, double zn,
			     SplineInfo& spinfo, BsplineResult* bspres);


int	process(Common *c);

void	eval_splines( SplineInfo& spinfo,
		      int max_num,
		      std::string label,
		      std::string outfile,
		      EvalSpline      func_eval,
		      EvalSplineDeriv func_eval_deriv
		      );

#endif /* _MAIN_H */
