#include <fstream>
#include <iostream>
using namespace std;

#include <BsplineEval/spline_coef.h>
#include <BsplineEval/bsplineval.h>

#include "main.h"
#include "spline_io.h"

#include "bspline.h"

#ifdef HAVE_DASL_DBL
#include "dasl.h"
#endif

int process( Common *c ) {

  SplineInfo spinfo;

  spinfo.scoef = read_spline_data( c->input );
  spinfo.bsp = Bspline_init( &spinfo.scoef );

  if ( NULL == spinfo.bsp ) {
    cerr << "process( ) : Unable to allocate memory for eval_spline" << endl;
    return EXIT_FAILURE;
  }

#ifdef HAVE_DASL_DBL
  alloc_spline_workspaces( spinfo );
#endif

  eval_splines( spinfo, c->num, "optc", c->prefix + "optc.out",
		bspline_eval, bspline_eval_derivs );

  char methods[] = { 'a', 'b' };
  for ( size_t m1 = 0 ; m1 < sizeof(methods) ; m1++ )
    for ( size_t m2 = 0 ; m2 < sizeof(methods) ; m2++ )
    {
      char mth1 = methods[m1];
      char mth2 = methods[m2];
      spinfo.bsp->method1 = mth1;
      spinfo.bsp->method2 = mth2;

      std::string label = (string) "algc_" +  mth1 +  mth2;

      eval_splines( spinfo, c->num, label, c->prefix + label + ".out",
		    bspline_algc_eval, bspline_algc_eval_derivs );
    }
  


#ifdef HAVE_DASL_DBL
  eval_splines( spinfo, c->num, "dasl", c->prefix + "dasl.out",
		dasl_eval, dasl_eval_derivs );
#endif


#ifdef HAVE_DASL_DBL
  free_spline_workspaces( spinfo );
#endif

  Bspline_free( spinfo.bsp );

  free_spline_coefs( spinfo.scoef );

  return EXIT_SUCCESS;

}



